# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class WorkflowsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def workflows_add_version_to_workflow(
        self,
        workflow_id,
        file,
        name,
        owner_id,
        others_may_download,
        others_can_execute,
        execution_mode,
        make_published,
        workflow_credential_type,
        **kwargs,
    ):  # noqa: E501
        """Upload a new version of an existing workflow.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_add_version_to_workflow(workflow_id, file, name, owner_id, others_may_download,
          others_can_execute, execution_mode, make_published, workflow_credential_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param file file: Must use a workflow package (.yxzp). (required)
        :param str name: Name for the updated version of the workflow. (required)
        :param str owner_id: Identifier for the owner of the new version of the workflow. (required)
        :param bool others_may_download:  (required)
        :param bool others_can_execute:  (required)
        :param str execution_mode:  (required)
        :param bool make_published: Updates this new version as the published version of the workflow. (required)
        :param str workflow_credential_type:  (required)
        :param bool has_private_data_exemption:
        :param str comments:
        :param str credential_id: Identifier for existing credentials used within the workflow.
        :return: WorkflowView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_add_version_to_workflow_with_http_info(
                workflow_id,
                file,
                name,
                owner_id,
                others_may_download,
                others_can_execute,
                execution_mode,
                make_published,
                workflow_credential_type,
                **kwargs,
            )  # noqa: E501
        else:
            (data) = self.workflows_add_version_to_workflow_with_http_info(
                workflow_id,
                file,
                name,
                owner_id,
                others_may_download,
                others_can_execute,
                execution_mode,
                make_published,
                workflow_credential_type,
                **kwargs,
            )  # noqa: E501
            return data

    def workflows_add_version_to_workflow_with_http_info(
        self,
        workflow_id,
        file,
        name,
        owner_id,
        others_may_download,
        others_can_execute,
        execution_mode,
        make_published,
        workflow_credential_type,
        **kwargs,
    ):  # noqa: E501
        """Upload a new version of an existing workflow.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_add_version_to_workflow_with_http_info(workflow_id, file, name, owner_id,
          others_may_download, others_can_execute, execution_mode, make_published, workflow_credential_type,
            async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param file file: Must use a workflow package (.yxzp). (required)
        :param str name: Name for the updated version of the workflow. (required)
        :param str owner_id: Identifier for the owner of the new version of the workflow. (required)
        :param bool others_may_download:  (required)
        :param bool others_can_execute:  (required)
        :param str execution_mode:  (required)
        :param bool make_published: Updates this new version as the published version of the workflow. (required)
        :param str workflow_credential_type:  (required)
        :param bool has_private_data_exemption:
        :param str comments:
        :param str credential_id: Identifier for existing credentials used within the workflow.
        :return: WorkflowView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "workflow_id",
            "file",
            "name",
            "owner_id",
            "others_may_download",
            "others_can_execute",
            "execution_mode",
            "make_published",
            "workflow_credential_type",
            "has_private_data_exemption",
            "comments",
            "credential_id",
        ]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method workflows_add_version_to_workflow" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'workflow_id' is set
        if self.api_client.client_side_validation and ("workflow_id" not in params or params["workflow_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `workflow_id` when calling `workflows_add_version_to_workflow`"
            )  # noqa: E501
        # verify the required parameter 'file' is set
        if self.api_client.client_side_validation and ("file" not in params or params["file"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `file` when calling `workflows_add_version_to_workflow`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ("name" not in params or params["name"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `workflows_add_version_to_workflow`")  # noqa: E501
        # verify the required parameter 'owner_id' is set
        if self.api_client.client_side_validation and ("owner_id" not in params or params["owner_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `owner_id` when calling `workflows_add_version_to_workflow`"
            )  # noqa: E501
        # verify the required parameter 'others_may_download' is set
        if self.api_client.client_side_validation and (
            "others_may_download" not in params or params["others_may_download"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `others_may_download` when calling `workflows_add_version_to_workflow`"
            )  # noqa: E501
        # verify the required parameter 'others_can_execute' is set
        if self.api_client.client_side_validation and (
            "others_can_execute" not in params or params["others_can_execute"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `others_can_execute` when calling `workflows_add_version_to_workflow`"
            )  # noqa: E501
        # verify the required parameter 'execution_mode' is set
        if self.api_client.client_side_validation and (
            "execution_mode" not in params or params["execution_mode"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `execution_mode` when calling `workflows_add_version_to_workflow`"
            )  # noqa: E501
        # verify the required parameter 'make_published' is set
        if self.api_client.client_side_validation and (
            "make_published" not in params or params["make_published"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `make_published` when calling `workflows_add_version_to_workflow`"
            )  # noqa: E501
        # verify the required parameter 'workflow_credential_type' is set
        if self.api_client.client_side_validation and (
            "workflow_credential_type" not in params or params["workflow_credential_type"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `workflow_credential_type` when calling "
                "`workflows_add_version_to_workflow`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "workflow_id" in params:
            path_params["workflowId"] = params["workflow_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if "file" in params:
            local_var_files["file"] = params["file"]  # noqa: E501
        if "name" in params:
            form_params.append(("name", params["name"]))  # noqa: E501
        if "owner_id" in params:
            form_params.append(("ownerId", params["owner_id"]))  # noqa: E501
        if "others_may_download" in params:
            form_params.append(("othersMayDownload", params["others_may_download"]))  # noqa: E501
        if "others_can_execute" in params:
            form_params.append(("othersCanExecute", params["others_can_execute"]))  # noqa: E501
        if "execution_mode" in params:
            form_params.append(("executionMode", params["execution_mode"]))  # noqa: E501
        if "has_private_data_exemption" in params:
            form_params.append(("hasPrivateDataExemption", params["has_private_data_exemption"]))  # noqa: E501
        if "comments" in params:
            form_params.append(("comments", params["comments"]))  # noqa: E501
        if "make_published" in params:
            form_params.append(("makePublished", params["make_published"]))  # noqa: E501
        if "workflow_credential_type" in params:
            form_params.append(("workflowCredentialType", params["workflow_credential_type"]))  # noqa: E501
        if "credential_id" in params:
            form_params.append(("credentialId", params["credential_id"]))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/form-data"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows/{workflowId}/versions",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="WorkflowView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def workflows_create_workflow(
        self,
        file,
        name,
        owner_id,
        is_public,
        is_ready_for_migration,
        others_may_download,
        others_can_execute,
        execution_mode,
        workflow_credential_type,
        **kwargs,
    ):  # noqa: E501
        """Upload a new workflow package.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_create_workflow(file, name, owner_id, is_public, is_ready_for_migration,
          others_may_download, others_can_execute, execution_mode, workflow_credential_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file: Must use a workflow package (.yxzp). (required)
        :param str name: (required)
        :param str owner_id: (required)
        :param bool is_public: (required)
        :param bool is_ready_for_migration: (required)
        :param bool others_may_download: (required)
        :param bool others_can_execute: (required)
        :param str execution_mode:  Accepted values are \"Safe\", \"SemiSafe\", \"Standard\",  (required)
        :param str workflow_credential_type:  Accepted values are \"Default\", \"Required\", \"Specific\",  (required)
        :param str worker_tag:
        :param str district_tags:  Submit as JSON formatted array. IE: [\"id1\", \"id2\"]
        :param str comments:
        :param str source_app_id:  Sets the source app id of a workflow. Can be used as the 'sourceId' reference for
          the POST admin/v1/workflows API endpoint. Providing an pre existing sourceAppId will result
            in an invalid request.
        :param bool has_private_data_exemption:
        :param str credential_id:
        :param str collection_ids:  Submit as JSON formatted array. IE: [\"id1\", \"id2\"]
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_create_workflow_with_http_info(
                file,
                name,
                owner_id,
                is_public,
                is_ready_for_migration,
                others_may_download,
                others_can_execute,
                execution_mode,
                workflow_credential_type,
                **kwargs,
            )  # noqa: E501
        else:
            (data) = self.workflows_create_workflow_with_http_info(
                file,
                name,
                owner_id,
                is_public,
                is_ready_for_migration,
                others_may_download,
                others_can_execute,
                execution_mode,
                workflow_credential_type,
                **kwargs,
            )  # noqa: E501
            return data

    def workflows_create_workflow_with_http_info(
        self,
        file,
        name,
        owner_id,
        is_public,
        is_ready_for_migration,
        others_may_download,
        others_can_execute,
        execution_mode,
        workflow_credential_type,
        **kwargs,
    ):  # noqa: E501
        """Upload a new workflow package.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_create_workflow_with_http_info(file, name, owner_id, is_public, 
        is_ready_for_migration, others_may_download, others_can_execute, execution_mode, workflow_credential_type,
          async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file: Must use a workflow package (.yxzp). (required)
        :param str name: (required)
        :param str owner_id: (required)
        :param bool is_public: (required)
        :param bool is_ready_for_migration: (required)
        :param bool others_may_download: (required)
        :param bool others_can_execute: (required)
        :param str execution_mode:  Accepted values are \"Safe\", \"SemiSafe\", \"Standard\",  (required)
        :param str workflow_credential_type:  Accepted values are \"Default\", \"Required\", \"Specific\",  (required)
        :param str worker_tag:
        :param str district_tags:  Submit as JSON formatted array. IE: [\"id1\", \"id2\"]
        :param str comments:
        :param str source_app_id:  Sets the source app id of a workflow. Can be used as the 'sourceId' reference for
          the POST admin/v1/workflows API endpoint. Providing an pre existing sourceAppId will result in an invalid
            request.
        :param bool has_private_data_exemption:
        :param str credential_id:
        :param str collection_ids:  Submit as JSON formatted array. IE: [\"id1\", \"id2\"]
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "file",
            "name",
            "owner_id",
            "is_public",
            "is_ready_for_migration",
            "others_may_download",
            "others_can_execute",
            "execution_mode",
            "workflow_credential_type",
            "worker_tag",
            "district_tags",
            "comments",
            "source_app_id",
            "has_private_data_exemption",
            "credential_id",
            "collection_ids",
        ]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method workflows_create_workflow" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'file' is set
        if self.api_client.client_side_validation and ("file" not in params or params["file"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `file` when calling `workflows_create_workflow`")  # noqa: E501
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ("name" not in params or params["name"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `name` when calling `workflows_create_workflow`")  # noqa: E501
        # verify the required parameter 'owner_id' is set
        if self.api_client.client_side_validation and ("owner_id" not in params or params["owner_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `owner_id` when calling `workflows_create_workflow`")  # noqa: E501
        # verify the required parameter 'is_public' is set
        if self.api_client.client_side_validation and ("is_public" not in params or params["is_public"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `is_public` when calling `workflows_create_workflow`")  # noqa: E501
        # verify the required parameter 'is_ready_for_migration' is set
        if self.api_client.client_side_validation and (
            "is_ready_for_migration" not in params or params["is_ready_for_migration"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `is_ready_for_migration` when calling `workflows_create_workflow`"
            )  # noqa: E501
        # verify the required parameter 'others_may_download' is set
        if self.api_client.client_side_validation and (
            "others_may_download" not in params or params["others_may_download"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `others_may_download` when calling `workflows_create_workflow`"
            )  # noqa: E501
        # verify the required parameter 'others_can_execute' is set
        if self.api_client.client_side_validation and (
            "others_can_execute" not in params or params["others_can_execute"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `others_can_execute` when calling `workflows_create_workflow`"
            )  # noqa: E501
        # verify the required parameter 'execution_mode' is set
        if self.api_client.client_side_validation and (
            "execution_mode" not in params or params["execution_mode"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `execution_mode` when calling `workflows_create_workflow`")  # noqa: E501
        # verify the required parameter 'workflow_credential_type' is set
        if self.api_client.client_side_validation and (
            "workflow_credential_type" not in params or params["workflow_credential_type"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `workflow_credential_type` when calling `workflows_create_workflow`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if "file" in params:
            local_var_files["file"] = params["file"]  # noqa: E501
        if "name" in params:
            form_params.append(("name", params["name"]))  # noqa: E501
        if "owner_id" in params:
            form_params.append(("ownerId", params["owner_id"]))  # noqa: E501
        if "worker_tag" in params:
            form_params.append(("workerTag", params["worker_tag"]))  # noqa: E501
        if "district_tags" in params:
            form_params.append(("districtTags", params["district_tags"]))  # noqa: E501
        if "comments" in params:
            form_params.append(("comments", params["comments"]))  # noqa: E501
        if "is_public" in params:
            form_params.append(("isPublic", params["is_public"]))  # noqa: E501
        if "is_ready_for_migration" in params:
            form_params.append(("isReadyForMigration", params["is_ready_for_migration"]))  # noqa: E501
        if "source_app_id" in params:
            form_params.append(("sourceAppId", params["source_app_id"]))  # noqa: E501
        if "others_may_download" in params:
            form_params.append(("othersMayDownload", params["others_may_download"]))  # noqa: E501
        if "others_can_execute" in params:
            form_params.append(("othersCanExecute", params["others_can_execute"]))  # noqa: E501
        if "execution_mode" in params:
            form_params.append(("executionMode", params["execution_mode"]))  # noqa: E501
        if "has_private_data_exemption" in params:
            form_params.append(("hasPrivateDataExemption", params["has_private_data_exemption"]))  # noqa: E501
        if "workflow_credential_type" in params:
            form_params.append(("workflowCredentialType", params["workflow_credential_type"]))  # noqa: E501
        if "credential_id" in params:
            form_params.append(("credentialId", params["credential_id"]))  # noqa: E501
        if "collection_ids" in params:
            form_params.append(("collectionIds", params["collection_ids"]))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/form-data"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="str",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def workflows_delete_workflow(self, workflow_id, **kwargs):  # noqa: E501
        """Delete an existing workflow.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_delete_workflow(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param bool force: If the workflow is scheduled, setting force to True will delete all impacted
          schedules before deleting the workflow.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_delete_workflow_with_http_info(workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.workflows_delete_workflow_with_http_info(workflow_id, **kwargs)  # noqa: E501
            return data

    def workflows_delete_workflow_with_http_info(self, workflow_id, **kwargs):  # noqa: E501
        """Delete an existing workflow.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_delete_workflow_with_http_info(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param bool force: If the workflow is scheduled, setting force to True will delete all impacted schedule
        s before deleting the workflow.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["workflow_id", "force"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method workflows_delete_workflow" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'workflow_id' is set
        if self.api_client.client_side_validation and ("workflow_id" not in params or params["workflow_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflows_delete_workflow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "workflow_id" in params:
            path_params["workflowId"] = params["workflow_id"]  # noqa: E501

        query_params = []
        if "force" in params:
            query_params.append(("force", params["force"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows/{workflowId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def workflows_download_workflow(self, workflow_id, **kwargs):  # noqa: E501
        """Download a copy of an existing workflow package.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_download_workflow(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param str version_id: A specific version number of the workflow. If no version is provided,
          the published version will be downloaded.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_download_workflow_with_http_info(workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.workflows_download_workflow_with_http_info(workflow_id, **kwargs)  # noqa: E501
            return data

    def workflows_download_workflow_with_http_info(self, workflow_id, **kwargs):  # noqa: E501
        """Download a copy of an existing workflow package.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_download_workflow_with_http_info(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param str version_id: A specific version number of the workflow. If no version is provided,
          the published version will be downloaded.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["workflow_id", "version_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method workflows_download_workflow" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'workflow_id' is set
        if self.api_client.client_side_validation and ("workflow_id" not in params or params["workflow_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflows_download_workflow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "workflow_id" in params:
            path_params["workflowId"] = params["workflow_id"]  # noqa: E501

        query_params = []
        if "version_id" in params:
            query_params.append(("versionId", params["version_id"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/octet-stream"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows/{workflowId}/package",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def workflows_enqueue(self, workflow_id, contract, **kwargs):  # noqa: E501
        """Creates a new job and adds it to the job execution queue.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_enqueue(workflow_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param EnqueueJobContract contract:  (required)
        :return: JobView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_enqueue_with_http_info(workflow_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.workflows_enqueue_with_http_info(workflow_id, contract, **kwargs)  # noqa: E501
            return data

    def workflows_enqueue_with_http_info(self, workflow_id, contract, **kwargs):  # noqa: E501
        """Creates a new job and adds it to the job execution queue.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_enqueue_with_http_info(workflow_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param EnqueueJobContract contract:  (required)
        :return: JobView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["workflow_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method workflows_enqueue" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'workflow_id' is set
        if self.api_client.client_side_validation and ("workflow_id" not in params or params["workflow_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflows_enqueue`")  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `contract` when calling `workflows_enqueue`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "workflow_id" in params:
            path_params["workflowId"] = params["workflow_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows/{workflowId}/jobs",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="JobView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def workflows_get_jobs_for_workflow(self, workflow_id, **kwargs):  # noqa: E501
        """Retrieve a list of jobs for an existing workflow.  # noqa: E501

        A Job may be returned as Completed even if the query status is Error.
          This would indicate an error occurred during  execution, but the workflow was run.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_get_jobs_for_workflow(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param str sort_field:
        :param str direction:
        :param str offset:
        :param str limit:
        :param str status: The overall status of the job execution. A completed job may still have failed.
        :param str result_code: The result code of the execution of a workflow. This can indicate a failed workflow,
          but a successful job.
        :return: list[WorkflowJobView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_get_jobs_for_workflow_with_http_info(workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.workflows_get_jobs_for_workflow_with_http_info(workflow_id, **kwargs)  # noqa: E501
            return data

    def workflows_get_jobs_for_workflow_with_http_info(self, workflow_id, **kwargs):  # noqa: E501
        """Retrieve a list of jobs for an existing workflow.  # noqa: E501

        A Job may be returned as Completed even if the query status is Error. This would indicate an error occurred
          during  execution, but the workflow was run.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_get_jobs_for_workflow_with_http_info(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param str sort_field:
        :param str direction:
        :param str offset:
        :param str limit:
        :param str status: The overall status of the job execution. A completed job may still have failed.
        :param str result_code: The result code of the execution of a workflow. This can indicate a failed workflow,
          but a successful job.
        :return: list[WorkflowJobView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["workflow_id", "sort_field", "direction", "offset", "limit", "status", "result_code"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method workflows_get_jobs_for_workflow" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'workflow_id' is set
        if self.api_client.client_side_validation and ("workflow_id" not in params or params["workflow_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `workflow_id` when calling `workflows_get_jobs_for_workflow`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "workflow_id" in params:
            path_params["workflowId"] = params["workflow_id"]  # noqa: E501

        query_params = []
        if "sort_field" in params:
            query_params.append(("sortField", params["sort_field"]))  # noqa: E501
        if "direction" in params:
            query_params.append(("direction", params["direction"]))  # noqa: E501
        if "offset" in params:
            query_params.append(("offset", params["offset"]))  # noqa: E501
        if "limit" in params:
            query_params.append(("limit", params["limit"]))  # noqa: E501
        if "status" in params:
            query_params.append(("status", params["status"]))  # noqa: E501
        if "result_code" in params:
            query_params.append(("resultCode", params["result_code"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows/{workflowId}/jobs",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[WorkflowJobView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def workflows_get_workflow(self, workflow_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing workflow.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_get_workflow(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :return: WorkflowView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_get_workflow_with_http_info(workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.workflows_get_workflow_with_http_info(workflow_id, **kwargs)  # noqa: E501
            return data

    def workflows_get_workflow_with_http_info(self, workflow_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing workflow.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_get_workflow_with_http_info(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :return: WorkflowView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["workflow_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method workflows_get_workflow" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'workflow_id' is set
        if self.api_client.client_side_validation and ("workflow_id" not in params or params["workflow_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflows_get_workflow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "workflow_id" in params:
            path_params["workflowId"] = params["workflow_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows/{workflowId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="WorkflowView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def workflows_get_workflow_questions(self, workflow_id, **kwargs):  # noqa: E501
        """Retrieve question information for an analytic app.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_get_workflow_questions(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param str version_id: A specific version number of the workflow to get questions of.
        :return: list[WorkflowQuestionView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_get_workflow_questions_with_http_info(workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.workflows_get_workflow_questions_with_http_info(workflow_id, **kwargs)  # noqa: E501
            return data

    def workflows_get_workflow_questions_with_http_info(self, workflow_id, **kwargs):  # noqa: E501
        """Retrieve question information for an analytic app.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_get_workflow_questions_with_http_info(workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param str version_id: A specific version number of the workflow to get questions of.
        :return: list[WorkflowQuestionView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["workflow_id", "version_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method workflows_get_workflow_questions" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'workflow_id' is set
        if self.api_client.client_side_validation and ("workflow_id" not in params or params["workflow_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `workflow_id` when calling `workflows_get_workflow_questions`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "workflow_id" in params:
            path_params["workflowId"] = params["workflow_id"]  # noqa: E501

        query_params = []
        if "version_id" in params:
            query_params.append(("versionId", params["version_id"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows/{workflowId}/questions",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[WorkflowQuestionView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def workflows_get_workflows(self, **kwargs):  # noqa: E501
        """Retrieve all accessible workflow records.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_get_workflows(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view:
        :param str name: Filter results by a specific workflow name.
        :param str owner_id: Filter results for a specific owner.
        :param str created_after: Filter results based on the published revision's created date, inclusive.
        :param str created_before: Filter results based on the published revision's created date, inclusive.
        :return: list[ReducedWorkflowView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_get_workflows_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.workflows_get_workflows_with_http_info(**kwargs)  # noqa: E501
            return data

    def workflows_get_workflows_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve all accessible workflow records.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_get_workflows_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view:
        :param str name: Filter results by a specific workflow name.
        :param str owner_id: Filter results for a specific owner.
        :param str created_after: Filter results based on the published revision's created date, inclusive.
        :param str created_before: Filter results based on the published revision's created date, inclusive.
        :return: list[ReducedWorkflowView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["view", "name", "owner_id", "created_after", "created_before"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method workflows_get_workflows" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "view" in params:
            query_params.append(("view", params["view"]))  # noqa: E501
        if "name" in params:
            query_params.append(("name", params["name"]))  # noqa: E501
        if "owner_id" in params:
            query_params.append(("ownerId", params["owner_id"]))  # noqa: E501
        if "created_after" in params:
            query_params.append(("createdAfter", params["created_after"]))  # noqa: E501
        if "created_before" in params:
            query_params.append(("createdBefore", params["created_before"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[ReducedWorkflowView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def workflows_transfer_workflow(self, workflow_id, contract, **kwargs):  # noqa: E501
        """Transfer specified workflow to specified owner and also schedules if desired  # noqa: E501

        If any of the workflows require DCM connections, server connections, or specific run as credentials to run, 
        these items will need to be updated before the workflow can run.   
        Additionally, if users are not in the same studio, 
        when a workflow is transferred to the new studio, all other users in the new owner's studio will also receive 
        access to the workflow,   and all users from the old studio will lose access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_transfer_workflow(workflow_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Id of the workflow to transfer (required)
        :param TransferWorkflowContract contract:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_transfer_workflow_with_http_info(workflow_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.workflows_transfer_workflow_with_http_info(workflow_id, contract, **kwargs)  # noqa: E501
            return data

    def workflows_transfer_workflow_with_http_info(self, workflow_id, contract, **kwargs):  # noqa: E501
        """Transfer specified workflow to specified owner and also schedules if desired  # noqa: E501

        If any of the workflows require DCM connections, server connections, or specific run as credentials to run, 
        these items will need to be updated before the workflow can run.   Additionally, if users are not in the same
        studio, when a workflow is transferred to the new studio, all other users in the new owner's studio will also 
        receive access to the workflow,   and all users from the old studio will lose access.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_transfer_workflow_with_http_info(workflow_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Id of the workflow to transfer (required)
        :param TransferWorkflowContract contract:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["workflow_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method workflows_transfer_workflow" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'workflow_id' is set
        if self.api_client.client_side_validation and ("workflow_id" not in params or params["workflow_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflows_transfer_workflow`")  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `contract` when calling `workflows_transfer_workflow`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "workflow_id" in params:
            path_params["workflowId"] = params["workflow_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows/{workflowId}/transfer",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def workflows_update_workflow(self, workflow_id, update_workflow_contract, **kwargs):  # noqa: E501
        """Update details of an existing workflow.  # noqa: E501

        Only Curators can use this API endpoint.   To change the ownerId, the new owner must be in the same subscription
          as the current owner.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_update_workflow(workflow_id, update_workflow_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param UpdateWorkflowContract update_workflow_contract:  (required)
        :return: WorkflowView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.workflows_update_workflow_with_http_info(workflow_id, update_workflow_contract, **kwargs)  # noqa: E501
        else:
            (data) = self.workflows_update_workflow_with_http_info(workflow_id, update_workflow_contract, **kwargs)  # noqa: E501
            return data

    def workflows_update_workflow_with_http_info(self, workflow_id, update_workflow_contract, **kwargs):  # noqa: E501
        """Update details of an existing workflow.  # noqa: E501

        Only Curators can use this API endpoint.   To change the ownerId, the new owner must be in the same subscription
          as the current owner.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.workflows_update_workflow_with_http_info(workflow_id, update_workflow_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str workflow_id: Identifier for an existing workflow or app (required)
        :param UpdateWorkflowContract update_workflow_contract:  (required)
        :return: WorkflowView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["workflow_id", "update_workflow_contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method workflows_update_workflow" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'workflow_id' is set
        if self.api_client.client_side_validation and ("workflow_id" not in params or params["workflow_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `workflow_id` when calling `workflows_update_workflow`")  # noqa: E501
        # verify the required parameter 'update_workflow_contract' is set
        if self.api_client.client_side_validation and (
            "update_workflow_contract" not in params or params["update_workflow_contract"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `update_workflow_contract` when calling `workflows_update_workflow`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "workflow_id" in params:
            path_params["workflowId"] = params["workflow_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_workflow_contract" in params:
            body_params = params["update_workflow_contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/workflows/{workflowId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="WorkflowView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class CollectionView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "name": "str",
        "owner_id": "str",
        "date_added": "datetime",
        "workflow_ids": "list[str]",
        "users": "list[CollectionUserView]",
        "subscription_ids": "list[str]",
        "user_group_ids": "list[str]",
        "schedule_ids": "list[str]",
    }

    attribute_map = {
        "id": "id",
        "name": "name",
        "owner_id": "ownerId",
        "date_added": "dateAdded",
        "workflow_ids": "workflowIds",
        "users": "users",
        "subscription_ids": "subscriptionIds",
        "user_group_ids": "userGroupIds",
        "schedule_ids": "scheduleIds",
    }

    def __init__(
        self,
        id=None,
        name=None,
        owner_id=None,
        date_added=None,
        workflow_ids=None,
        users=None,
        subscription_ids=None,
        user_group_ids=None,
        schedule_ids=None,
        _configuration=None,
    ):  # noqa: E501
        """CollectionView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._owner_id = None
        self._date_added = None
        self._workflow_ids = None
        self._users = None
        self._subscription_ids = None
        self._user_group_ids = None
        self._schedule_ids = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.owner_id = owner_id
        self.date_added = date_added
        if workflow_ids is not None:
            self.workflow_ids = workflow_ids
        if users is not None:
            self.users = users
        if subscription_ids is not None:
            self.subscription_ids = subscription_ids
        if user_group_ids is not None:
            self.user_group_ids = user_group_ids
        if schedule_ids is not None:
            self.schedule_ids = schedule_ids

    @property
    def id(self):
        """Gets the id of this CollectionView.  # noqa: E501


        :return: The id of this CollectionView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CollectionView.


        :param id: The id of this CollectionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this CollectionView.  # noqa: E501


        :return: The name of this CollectionView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CollectionView.


        :param name: The name of this CollectionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def owner_id(self):
        """Gets the owner_id of this CollectionView.  # noqa: E501


        :return: The owner_id of this CollectionView.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this CollectionView.


        :param owner_id: The owner_id of this CollectionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and owner_id is None:
            raise ValueError("Invalid value for `owner_id`, must not be `None`")  # noqa: E501

        self._owner_id = owner_id

    @property
    def date_added(self):
        """Gets the date_added of this CollectionView.  # noqa: E501


        :return: The date_added of this CollectionView.  # noqa: E501
        :rtype: datetime
        """
        return self._date_added

    @date_added.setter
    def date_added(self, date_added):
        """Sets the date_added of this CollectionView.


        :param date_added: The date_added of this CollectionView.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and date_added is None:
            raise ValueError("Invalid value for `date_added`, must not be `None`")  # noqa: E501

        self._date_added = date_added

    @property
    def workflow_ids(self):
        """Gets the workflow_ids of this CollectionView.  # noqa: E501


        :return: The workflow_ids of this CollectionView.  # noqa: E501
        :rtype: list[str]
        """
        return self._workflow_ids

    @workflow_ids.setter
    def workflow_ids(self, workflow_ids):
        """Sets the workflow_ids of this CollectionView.


        :param workflow_ids: The workflow_ids of this CollectionView.  # noqa: E501
        :type: list[str]
        """

        self._workflow_ids = workflow_ids

    @property
    def users(self):
        """Gets the users of this CollectionView.  # noqa: E501


        :return: The users of this CollectionView.  # noqa: E501
        :rtype: list[CollectionUserView]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this CollectionView.


        :param users: The users of this CollectionView.  # noqa: E501
        :type: list[CollectionUserView]
        """

        self._users = users

    @property
    def subscription_ids(self):
        """Gets the subscription_ids of this CollectionView.  # noqa: E501


        :return: The subscription_ids of this CollectionView.  # noqa: E501
        :rtype: list[str]
        """
        return self._subscription_ids

    @subscription_ids.setter
    def subscription_ids(self, subscription_ids):
        """Sets the subscription_ids of this CollectionView.


        :param subscription_ids: The subscription_ids of this CollectionView.  # noqa: E501
        :type: list[str]
        """

        self._subscription_ids = subscription_ids

    @property
    def user_group_ids(self):
        """Gets the user_group_ids of this CollectionView.  # noqa: E501


        :return: The user_group_ids of this CollectionView.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_group_ids

    @user_group_ids.setter
    def user_group_ids(self, user_group_ids):
        """Sets the user_group_ids of this CollectionView.


        :param user_group_ids: The user_group_ids of this CollectionView.  # noqa: E501
        :type: list[str]
        """

        self._user_group_ids = user_group_ids

    @property
    def schedule_ids(self):
        """Gets the schedule_ids of this CollectionView.  # noqa: E501


        :return: The schedule_ids of this CollectionView.  # noqa: E501
        :rtype: list[str]
        """
        return self._schedule_ids

    @schedule_ids.setter
    def schedule_ids(self, schedule_ids):
        """Sets the schedule_ids of this CollectionView.


        :param schedule_ids: The schedule_ids of this CollectionView.  # noqa: E501
        :type: list[str]
        """

        self._schedule_ids = schedule_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CollectionView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CollectionView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class SubscriptionsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def subscriptions_change_users_subscription(self, subscription_id, contract, **kwargs):  # noqa: E501
        """Change users subscription.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_change_users_subscription(subscription_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id: Identifier for an existing subscription. (required)
        :param ChangeUsersSubscriptionContract contract: The request body structure required to change users subscription. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.subscriptions_change_users_subscription_with_http_info(subscription_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.subscriptions_change_users_subscription_with_http_info(subscription_id, contract, **kwargs)  # noqa: E501
            return data

    def subscriptions_change_users_subscription_with_http_info(self, subscription_id, contract, **kwargs):  # noqa: E501
        """Change users subscription.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_change_users_subscription_with_http_info(subscription_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id: Identifier for an existing subscription. (required)
        :param ChangeUsersSubscriptionContract contract: The request body structure required to change users subscription. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["subscription_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method subscriptions_change_users_subscription" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'subscription_id' is set
        if self.api_client.client_side_validation and (
            "subscription_id" not in params or params["subscription_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `subscription_id` when calling `subscriptions_change_users_subscription`"
            )  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `contract` when calling `subscriptions_change_users_subscription`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "subscription_id" in params:
            path_params["subscriptionId"] = params["subscription_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/subscriptions/{subscriptionId}/users",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def subscriptions_create_subscription(self, contract, **kwargs):  # noqa: E501
        """Create new subscription.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_create_subscription(contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateSubscriptionContract contract: The request body structure required to make a new Subscription. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.subscriptions_create_subscription_with_http_info(contract, **kwargs)  # noqa: E501
        else:
            (data) = self.subscriptions_create_subscription_with_http_info(contract, **kwargs)  # noqa: E501
            return data

    def subscriptions_create_subscription_with_http_info(self, contract, **kwargs):  # noqa: E501
        """Create new subscription.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_create_subscription_with_http_info(contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateSubscriptionContract contract: The request body structure required to make a new Subscription. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method subscriptions_create_subscription" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `contract` when calling `subscriptions_create_subscription`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/subscriptions",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def subscriptions_delete_subscription(self, subscription_id, **kwargs):  # noqa: E501
        """Delete an existing subscription.  # noqa: E501

        Only Curators can use this API endpoint.  Subscriptions can only be deleted if no workflows or users are in the studio.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_delete_subscription(subscription_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id: Identifier for an existing subscription. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.subscriptions_delete_subscription_with_http_info(subscription_id, **kwargs)  # noqa: E501
        else:
            (data) = self.subscriptions_delete_subscription_with_http_info(subscription_id, **kwargs)  # noqa: E501
            return data

    def subscriptions_delete_subscription_with_http_info(self, subscription_id, **kwargs):  # noqa: E501
        """Delete an existing subscription.  # noqa: E501

        Only Curators can use this API endpoint.  Subscriptions can only be deleted if no workflows or users are in the studio.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_delete_subscription_with_http_info(subscription_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id: Identifier for an existing subscription. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["subscription_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method subscriptions_delete_subscription" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'subscription_id' is set
        if self.api_client.client_side_validation and (
            "subscription_id" not in params or params["subscription_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `subscription_id` when calling `subscriptions_delete_subscription`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if "subscription_id" in params:
            query_params.append(("subscriptionId", params["subscription_id"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/subscriptions",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def subscriptions_get_subscription_by_id(self, subscription_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing subscription.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_get_subscription_by_id(subscription_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id: Identifier for an existing subscription. (required)
        :return: SubscriptionUserWorkflowDetailsView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.subscriptions_get_subscription_by_id_with_http_info(subscription_id, **kwargs)  # noqa: E501
        else:
            (data) = self.subscriptions_get_subscription_by_id_with_http_info(subscription_id, **kwargs)  # noqa: E501
            return data

    def subscriptions_get_subscription_by_id_with_http_info(self, subscription_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing subscription.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_get_subscription_by_id_with_http_info(subscription_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id: Identifier for an existing subscription. (required)
        :return: SubscriptionUserWorkflowDetailsView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["subscription_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method subscriptions_get_subscription_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'subscription_id' is set
        if self.api_client.client_side_validation and (
            "subscription_id" not in params or params["subscription_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `subscription_id` when calling `subscriptions_get_subscription_by_id`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "subscription_id" in params:
            path_params["subscriptionId"] = params["subscription_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/subscriptions/{subscriptionId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SubscriptionUserWorkflowDetailsView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def subscriptions_get_subscriptions(self, **kwargs):  # noqa: E501
        """Retrieve details about existing subscriptions.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_get_subscriptions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name:
        :param bool can_share_schedule:
        :param str default_workflow_credential_id:
        :param int user_count_greater_than_equals:
        :param int user_count_less_than_equals:
        :param int workflow_count_greater_than_equals:
        :param int workflow_count_less_than_equals:
        :return: list[SubscriptionUserWorkflowCountView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.subscriptions_get_subscriptions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.subscriptions_get_subscriptions_with_http_info(**kwargs)  # noqa: E501
            return data

    def subscriptions_get_subscriptions_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve details about existing subscriptions.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_get_subscriptions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name:
        :param bool can_share_schedule:
        :param str default_workflow_credential_id:
        :param int user_count_greater_than_equals:
        :param int user_count_less_than_equals:
        :param int workflow_count_greater_than_equals:
        :param int workflow_count_less_than_equals:
        :return: list[SubscriptionUserWorkflowCountView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "name",
            "can_share_schedule",
            "default_workflow_credential_id",
            "user_count_greater_than_equals",
            "user_count_less_than_equals",
            "workflow_count_greater_than_equals",
            "workflow_count_less_than_equals",
        ]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method subscriptions_get_subscriptions" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "name" in params:
            query_params.append(("name", params["name"]))  # noqa: E501
        if "can_share_schedule" in params:
            query_params.append(("canShareSchedule", params["can_share_schedule"]))  # noqa: E501
        if "default_workflow_credential_id" in params:
            query_params.append(("defaultWorkflowCredentialId", params["default_workflow_credential_id"]))  # noqa: E501
        if "user_count_greater_than_equals" in params:
            query_params.append(("userCountGreaterThanEquals", params["user_count_greater_than_equals"]))  # noqa: E501
        if "user_count_less_than_equals" in params:
            query_params.append(("userCountLessThanEquals", params["user_count_less_than_equals"]))  # noqa: E501
        if "workflow_count_greater_than_equals" in params:
            query_params.append(("workflowCountGreaterThanEquals", params["workflow_count_greater_than_equals"]))  # noqa: E501
        if "workflow_count_less_than_equals" in params:
            query_params.append(("workflowCountLessThanEquals", params["workflow_count_less_than_equals"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/subscriptions",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[SubscriptionUserWorkflowCountView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def subscriptions_update_subscription(self, subscription_id, subscription, **kwargs):  # noqa: E501
        """Update an existing subscription.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_update_subscription(subscription_id, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id: Identifier for an existing subscription. (required)
        :param UpdateSubscriptionContract subscription:  (required)
        :return: SubscriptionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.subscriptions_update_subscription_with_http_info(subscription_id, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.subscriptions_update_subscription_with_http_info(subscription_id, subscription, **kwargs)  # noqa: E501
            return data

    def subscriptions_update_subscription_with_http_info(self, subscription_id, subscription, **kwargs):  # noqa: E501
        """Update an existing subscription.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.subscriptions_update_subscription_with_http_info(subscription_id, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str subscription_id: Identifier for an existing subscription. (required)
        :param UpdateSubscriptionContract subscription:  (required)
        :return: SubscriptionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["subscription_id", "subscription"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method subscriptions_update_subscription" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'subscription_id' is set
        if self.api_client.client_side_validation and (
            "subscription_id" not in params or params["subscription_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `subscription_id` when calling `subscriptions_update_subscription`"
            )  # noqa: E501
        # verify the required parameter 'subscription' is set
        if self.api_client.client_side_validation and ("subscription" not in params or params["subscription"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `subscription` when calling `subscriptions_update_subscription`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "subscription_id" in params:
            path_params["subscriptionId"] = params["subscription_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "subscription" in params:
            body_params = params["subscription"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/subscriptions/{subscriptionId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SubscriptionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

# flake8: noqa
"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from src.server_client.models.ad_object import ADObject
from src.server_client.models.active_directory_object_view import ActiveDirectoryObjectView
from src.server_client.models.add_credentials_user_contract import AddCredentialsUserContract
from src.server_client.models.add_credentials_user_group_contract import AddCredentialsUserGroupContract
from src.server_client.models.add_schedule_contract import AddScheduleContract
from src.server_client.models.add_server_connection_user_contract import AddServerConnectionUserContract
from src.server_client.models.add_server_connection_user_group_contract import AddServerConnectionUserGroupContract
from src.server_client.models.add_user_contract import AddUserContract
from src.server_client.models.add_user_group_contract import AddUserGroupContract
from src.server_client.models.add_workflow_contract import AddWorkflowContract
from src.server_client.models.affected_schedule_view import AffectedScheduleView
from src.server_client.models.app_value import AppValue
from src.server_client.models.asset_data_view import AssetDataView
from src.server_client.models.assets_view import AssetsView
from src.server_client.models.change_users_subscription_contract import ChangeUsersSubscriptionContract
from src.server_client.models.collection_user_view import CollectionUserView
from src.server_client.models.collection_view import CollectionView
from src.server_client.models.collections_permissions_view_contract import CollectionsPermissionsViewContract
from src.server_client.models.create_collection_contract import CreateCollectionContract
from src.server_client.models.create_schedule_contract import CreateScheduleContract
from src.server_client.models.create_subscription_contract import CreateSubscriptionContract
from src.server_client.models.create_user_contract import CreateUserContract
from src.server_client.models.create_user_group_contract import CreateUserGroupContract
from src.server_client.models.credentials_view import CredentialsView
from src.server_client.models.dcme_connection_handling_rule_contract import DCMEConnectionHandlingRuleContract
from src.server_client.models.dcme_credential_contract import DCMECredentialContract
from src.server_client.models.dcme_credential_view import DCMECredentialView
from src.server_client.models.dcme_data_source_contract import DCMEDataSourceContract
from src.server_client.models.dcme_data_source_for_connect_view import DCMEDataSourceForConnectView
from src.server_client.models.dcme_data_source_view import DCMEDataSourceView
from src.server_client.models.dcme_delete_connection_view import DCMEDeleteConnectionView
from src.server_client.models.dcme_get_connection_for_connect_view import DCMEGetConnectionForConnectView
from src.server_client.models.dcme_get_connection_view import DCMEGetConnectionView
from src.server_client.models.dcme_object_wrapper_contract_dcme_credential_contract import (
    DCMEObjectWrapperContractDCMECredentialContract,
)
from src.server_client.models.dcme_object_wrapper_contract_dcme_data_source_contract import (
    DCMEObjectWrapperContractDCMEDataSourceContract,
)
from src.server_client.models.dcme_secret_contract import DCMESecretContract
from src.server_client.models.dcme_secret_value_contract import DCMESecretValueContract
from src.server_client.models.dcme_secret_view import DCMESecretView
from src.server_client.models.dcme_share_for_collaboration_contract import DCMEShareForCollaborationContract
from src.server_client.models.dcme_share_for_execution_contract import DCMEShareForExecutionContract
from src.server_client.models.dcme_sharing_for_collaboration_view import DCMESharingForCollaborationView
from src.server_client.models.dcme_sharing_for_execution_view import DCMESharingForExecutionView
from src.server_client.models.dcme_sharing_view import DCMESharingView
from src.server_client.models.dcme_upsert_connection_admin_contract import DCMEUpsertConnectionAdminContract
from src.server_client.models.dcme_upsert_connection_contract import DCMEUpsertConnectionContract
from src.server_client.models.dcme_user_group_view import DCMEUserGroupView
from src.server_client.models.dcme_user_view import DCMEUserView
from src.server_client.models.deleted_connection_view import DeletedConnectionView
from src.server_client.models.deleted_credential_view import DeletedCredentialView
from src.server_client.models.deleted_data_source_view import DeletedDataSourceView
from src.server_client.models.enqueue_job_contract import EnqueueJobContract
from src.server_client.models.invalid_request_response_body import InvalidRequestResponseBody
from src.server_client.models.iteration_base import IterationBase
from src.server_client.models.iteration_contract import IterationContract
from src.server_client.models.iteration_custom_contract import IterationCustomContract
from src.server_client.models.iteration_daily_contract import IterationDailyContract
from src.server_client.models.iteration_hourly_contract import IterationHourlyContract
from src.server_client.models.iteration_monthly_contract import IterationMonthlyContract
from src.server_client.models.iteration_weekly_contract import IterationWeeklyContract
from src.server_client.models.job_message_view import JobMessageView
from src.server_client.models.job_view import JobView
from src.server_client.models.member import Member
from src.server_client.models.message_view import MessageView
from src.server_client.models.output_data_view import OutputDataView
from src.server_client.models.patch_schedule_contract import PatchScheduleContract
from src.server_client.models.reduced_collection_view import ReducedCollectionView
from src.server_client.models.reduced_credentials_view import ReducedCredentialsView
from src.server_client.models.reduced_schedule_view import ReducedScheduleView
from src.server_client.models.reduced_server_connection_view import ReducedServerConnectionView
from src.server_client.models.reduced_user_group_view import ReducedUserGroupView
from src.server_client.models.reduced_user_view import ReducedUserView
from src.server_client.models.reduced_workflow_view import ReducedWorkflowView
from src.server_client.models.schedule_view import ScheduleView
from src.server_client.models.search_subscription_contract import SearchSubscriptionContract
from src.server_client.models.search_user_contract import SearchUserContract
from src.server_client.models.server_connection_view import ServerConnectionView
from src.server_client.models.subscription import Subscription
from src.server_client.models.subscription_credential import SubscriptionCredential
from src.server_client.models.subscription_data_connection import SubscriptionDataConnection
from src.server_client.models.subscription_user_workflow_count_view import SubscriptionUserWorkflowCountView
from src.server_client.models.subscription_user_workflow_details_view import SubscriptionUserWorkflowDetailsView
from src.server_client.models.subscription_view import SubscriptionView
from src.server_client.models.transfer_user_assets_contract import TransferUserAssetsContract
from src.server_client.models.transfer_workflow_contract import TransferWorkflowContract
from src.server_client.models.update_collection_contract import UpdateCollectionContract
from src.server_client.models.update_permissions_contract import UpdatePermissionsContract
from src.server_client.models.update_schedule_contract import UpdateScheduleContract
from src.server_client.models.update_server_connection_contract import UpdateServerConnectionContract
from src.server_client.models.update_subscription_contract import UpdateSubscriptionContract
from src.server_client.models.update_user_contract import UpdateUserContract
from src.server_client.models.update_user_group_contract import UpdateUserGroupContract
from src.server_client.models.update_workflow_contract import UpdateWorkflowContract
from src.server_client.models.user_group_added_users_view import UserGroupAddedUsersView
from src.server_client.models.user_group_view import UserGroupView
from src.server_client.models.user_info import UserInfo
from src.server_client.models.user_view import UserView
from src.server_client.models.workflow_details import WorkflowDetails
from src.server_client.models.workflow_info import WorkflowInfo
from src.server_client.models.workflow_job_view import WorkflowJobView
from src.server_client.models.workflow_question_item_view import WorkflowQuestionItemView
from src.server_client.models.workflow_question_view import WorkflowQuestionView
from src.server_client.models.workflow_version_view import WorkflowVersionView
from src.server_client.models.workflow_view import WorkflowView



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class UserGroupsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def user_groups_add_active_directory_group_to_custom_group(self, user_group_id, sid, **kwargs):  # noqa: E501
        """Add an Active Directory group to an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  This endpoint can only be used for Windows Authentication configured
          Server instances.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_add_active_directory_group_to_custom_group(user_group_id, sid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param str sid: The identifier of the Active Directory group. This is a JSON body payload. You must submit the
          value wrapped in quotation marks such as: \"S-My-SID\". (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.user_groups_add_active_directory_group_to_custom_group_with_http_info(
                user_group_id, sid, **kwargs
            )  # noqa: E501
        else:
            (data) = self.user_groups_add_active_directory_group_to_custom_group_with_http_info(
                user_group_id, sid, **kwargs
            )  # noqa: E501
            return data

    def user_groups_add_active_directory_group_to_custom_group_with_http_info(self, user_group_id, sid, **kwargs):  # noqa: E501
        """Add an Active Directory group to an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  This endpoint can only be used for Windows Authentication configured
          Server instances.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_add_active_directory_group_to_custom_group_with_http_info(user_group_id, sid,
          async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param str sid: The identifier of the Active Directory group. This is a JSON body payload. You must submit the
          value wrapped in quotation marks such as: \"S-My-SID\". (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_group_id", "sid"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_groups_add_active_directory_group_to_custom_group" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_group_id` when calling "
                "`user_groups_add_active_directory_group_to_custom_group`"
            )  # noqa: E501
        # verify the required parameter 'sid' is set
        if self.api_client.client_side_validation and ("sid" not in params or params["sid"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `sid` when calling "
                "`user_groups_add_active_directory_group_to_custom_group`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "sid" in params:
            body_params = params["sid"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/usergroups/{userGroupId}/activedirectorygroups",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def user_groups_add_users_to_group(self, user_group_id, user_ids, **kwargs):  # noqa: E501
        """Add one or more existing users to an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_add_users_to_group(user_group_id, user_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param list[str] user_ids: List of user ids to add to the group, separated by commas. (required)
        :return: UserGroupAddedUsersView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.user_groups_add_users_to_group_with_http_info(user_group_id, user_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.user_groups_add_users_to_group_with_http_info(user_group_id, user_ids, **kwargs)  # noqa: E501
            return data

    def user_groups_add_users_to_group_with_http_info(self, user_group_id, user_ids, **kwargs):  # noqa: E501
        """Add one or more existing users to an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_add_users_to_group_with_http_info(user_group_id, user_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param list[str] user_ids: List of user ids to add to the group, separated by commas. (required)
        :return: UserGroupAddedUsersView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_group_id", "user_ids"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method user_groups_add_users_to_group" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_group_id` when calling `user_groups_add_users_to_group`"
            )  # noqa: E501
        # verify the required parameter 'user_ids' is set
        if self.api_client.client_side_validation and ("user_ids" not in params or params["user_ids"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_ids` when calling `user_groups_add_users_to_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "user_ids" in params:
            body_params = params["user_ids"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/usergroups/{userGroupId}/users",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserGroupAddedUsersView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def user_groups_create_user_group(self, contract, **kwargs):  # noqa: E501
        """Create a new user group.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_create_user_group(contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateUserGroupContract contract:  (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.user_groups_create_user_group_with_http_info(contract, **kwargs)  # noqa: E501
        else:
            (data) = self.user_groups_create_user_group_with_http_info(contract, **kwargs)  # noqa: E501
            return data

    def user_groups_create_user_group_with_http_info(self, contract, **kwargs):  # noqa: E501
        """Create a new user group.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_create_user_group_with_http_info(contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateUserGroupContract contract:  (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method user_groups_create_user_group" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `contract` when calling `user_groups_create_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/usergroups",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="str",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def user_groups_delete_user_group(self, user_group_id, **kwargs):  # noqa: E501
        """Delete an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  Will return a 400 Bad Request if the user group is not empty 
        and the forceDelete query param is false.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_delete_user_group(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param bool force_delete: Delete the user group even if the group is not empty
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.user_groups_delete_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.user_groups_delete_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
            return data

    def user_groups_delete_user_group_with_http_info(self, user_group_id, **kwargs):  # noqa: E501
        """Delete an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  Will return a 400 Bad Request if the user group is not empty 
        and the forceDelete query param is false.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_delete_user_group_with_http_info(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param bool force_delete: Delete the user group even if the group is not empty
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_group_id", "force_delete"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method user_groups_delete_user_group" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_group_id` when calling `user_groups_delete_user_group`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501

        query_params = []
        if "force_delete" in params:
            query_params.append(("forceDelete", params["force_delete"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/usergroups/{userGroupId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def user_groups_get_user_group(self, user_group_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing user group.  # noqa: E501

        Only Curators can use this API endpoint. Only works for Server user groups.   
        Active Directory groups cannot be retrieved from this endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_get_user_group(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :return: UserGroupView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.user_groups_get_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.user_groups_get_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
            return data

    def user_groups_get_user_group_with_http_info(self, user_group_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing user group.  # noqa: E501

        Only Curators can use this API endpoint. Only works for Server user groups.
              Active Directory groups cannot be retrieved from this endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_get_user_group_with_http_info(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :return: UserGroupView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_group_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method user_groups_get_user_group" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `user_group_id` when calling `user_groups_get_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/usergroups/{userGroupId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserGroupView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def user_groups_get_user_groups(self, **kwargs):  # noqa: E501
        """Retrieve all accessible user group records.  # noqa: E501

        Only Curators can use this API endpoint.  Only Custom User Groups will be retrieved. 
        No Active Directory Groups will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_get_user_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[ReducedUserGroupView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.user_groups_get_user_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.user_groups_get_user_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def user_groups_get_user_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve all accessible user group records.  # noqa: E501

        Only Curators can use this API endpoint.  Only Custom User Groups will be retrieved.
          No Active Directory Groups will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_get_user_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[ReducedUserGroupView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method user_groups_get_user_groups" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/usergroups",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[ReducedUserGroupView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def user_groups_remove_active_directory_group_from_custom_group(self, user_group_id, ad_group_sid, **kwargs):  # noqa: E501
        """Remove an Active Directory group from an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  This endpoint can only be used for Windows Authentication 
        configured Server instances.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_remove_active_directory_group_from_custom_group(user_group_id,
          ad_group_sid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param str ad_group_sid: Security identifer for an existing Microsoft Active Directory group. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.user_groups_remove_active_directory_group_from_custom_group_with_http_info(
                user_group_id, ad_group_sid, **kwargs
            )  # noqa: E501
        else:
            (data) = self.user_groups_remove_active_directory_group_from_custom_group_with_http_info(
                user_group_id, ad_group_sid, **kwargs
            )  # noqa: E501
            return data

    def user_groups_remove_active_directory_group_from_custom_group_with_http_info(
        self, user_group_id, ad_group_sid, **kwargs
    ):  # noqa: E501
        """Remove an Active Directory group from an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  This endpoint can only be used for Windows Authentication configured
          Server instances.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_remove_active_directory_group_from_custom_group_with_http_info(user_group_id,
          ad_group_sid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param str ad_group_sid: Security identifer for an existing Microsoft Active Directory group. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_group_id", "ad_group_sid"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_groups_remove_active_directory_group_from_custom_group" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_group_id` when calling "
                "`user_groups_remove_active_directory_group_from_custom_group`"
            )  # noqa: E501
        # verify the required parameter 'ad_group_sid' is set
        if self.api_client.client_side_validation and ("ad_group_sid" not in params or params["ad_group_sid"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `ad_group_sid` when calling "
                "`user_groups_remove_active_directory_group_from_custom_group`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501
        if "ad_group_sid" in params:
            path_params["adGroupSid"] = params["ad_group_sid"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/usergroups/{userGroupId}/activedirectorygroups/{adGroupSid}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def user_groups_remove_user_from_group(self, user_group_id, user_id, **kwargs):  # noqa: E501
        """Remove a user from an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  If the user is not a part of the user group, 
        then an OK response will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_remove_user_from_group(user_group_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param str user_id: Identifier for an existing user. (required)
        :return: UserGroupView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.user_groups_remove_user_from_group_with_http_info(user_group_id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.user_groups_remove_user_from_group_with_http_info(user_group_id, user_id, **kwargs)  # noqa: E501
            return data

    def user_groups_remove_user_from_group_with_http_info(self, user_group_id, user_id, **kwargs):  # noqa: E501
        """Remove a user from an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  If the user is not a part of the user group, 
        then an OK response will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_remove_user_from_group_with_http_info(user_group_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param str user_id: Identifier for an existing user. (required)
        :return: UserGroupView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_group_id", "user_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method user_groups_remove_user_from_group" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_group_id` when calling "
                "`user_groups_remove_user_from_group`"
            )  # noqa: E501
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_id` when calling "
                "`user_groups_remove_user_from_group`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/usergroups/{userGroupId}/users/{userId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserGroupView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def user_groups_update_user_group(self, user_group_id, contract, **kwargs):  # noqa: E501
        """Update name and/or role of an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_update_user_group(user_group_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param UpdateUserGroupContract contract:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.user_groups_update_user_group_with_http_info(user_group_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.user_groups_update_user_group_with_http_info(user_group_id, contract, **kwargs)  # noqa: E501
            return data

    def user_groups_update_user_group_with_http_info(self, user_group_id, contract, **kwargs):  # noqa: E501
        """Update name and/or role of an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_groups_update_user_group_with_http_info(user_group_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: Identifier for an existing user group. (required)
        :param UpdateUserGroupContract contract:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_group_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method user_groups_update_user_group" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_group_id` when calling `user_groups_update_user_group`"
            )  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `contract` when calling `user_groups_update_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/usergroups/{userGroupId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class WorkflowQuestionView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "name": "str",
        "question_type": "str",
        "description": "str",
        "value": "str",
        "multiple": "bool",
        "items": "list[WorkflowQuestionItemView]",
    }

    attribute_map = {
        "name": "name",
        "question_type": "questionType",
        "description": "description",
        "value": "value",
        "multiple": "multiple",
        "items": "items",
    }

    def __init__(
        self,
        name=None,
        question_type=None,
        description=None,
        value=None,
        multiple=None,
        items=None,
        _configuration=None,
    ):  # noqa: E501
        """WorkflowQuestionView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._question_type = None
        self._description = None
        self._value = None
        self._multiple = None
        self._items = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if question_type is not None:
            self.question_type = question_type
        if description is not None:
            self.description = description
        if value is not None:
            self.value = value
        if multiple is not None:
            self.multiple = multiple
        if items is not None:
            self.items = items

    @property
    def name(self):
        """Gets the name of this WorkflowQuestionView.  # noqa: E501


        :return: The name of this WorkflowQuestionView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowQuestionView.


        :param name: The name of this WorkflowQuestionView.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def question_type(self):
        """Gets the question_type of this WorkflowQuestionView.  # noqa: E501


        :return: The question_type of this WorkflowQuestionView.  # noqa: E501
        :rtype: str
        """
        return self._question_type

    @question_type.setter
    def question_type(self, question_type):
        """Sets the question_type of this WorkflowQuestionView.


        :param question_type: The question_type of this WorkflowQuestionView.  # noqa: E501
        :type: str
        """

        self._question_type = question_type

    @property
    def description(self):
        """Gets the description of this WorkflowQuestionView.  # noqa: E501


        :return: The description of this WorkflowQuestionView.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this WorkflowQuestionView.


        :param description: The description of this WorkflowQuestionView.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def value(self):
        """Gets the value of this WorkflowQuestionView.  # noqa: E501


        :return: The value of this WorkflowQuestionView.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this WorkflowQuestionView.


        :param value: The value of this WorkflowQuestionView.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def multiple(self):
        """Gets the multiple of this WorkflowQuestionView.  # noqa: E501


        :return: The multiple of this WorkflowQuestionView.  # noqa: E501
        :rtype: bool
        """
        return self._multiple

    @multiple.setter
    def multiple(self, multiple):
        """Sets the multiple of this WorkflowQuestionView.


        :param multiple: The multiple of this WorkflowQuestionView.  # noqa: E501
        :type: bool
        """

        self._multiple = multiple

    @property
    def items(self):
        """Gets the items of this WorkflowQuestionView.  # noqa: E501


        :return: The items of this WorkflowQuestionView.  # noqa: E501
        :rtype: list[WorkflowQuestionItemView]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this WorkflowQuestionView.


        :param items: The items of this WorkflowQuestionView.  # noqa: E501
        :type: list[WorkflowQuestionItemView]
        """

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(WorkflowQuestionView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowQuestionView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowQuestionView):
            return True

        return self.to_dict() != other.to_dict()
